import { Button, Input, InputProps, Space, message } from "antd"
import React, { useState } from "react"
import { useAjax } from "../hooks/useAjax"
import { smsSendApi } from "../api"
import { isMobile } from "../utils"

interface CodeInputProps extends InputProps {
    // 手机号码
    mobile: string
    msgType: 1 | 2 | 3 | 4
}
/**
 * 发送验证码 输入验证码框
 * @param props 
 * @returns 
 */
const CodeInput: React.FC<CodeInputProps> = ({ mobile, msgType, ...inputProps }) => {

    /*********************************/
    const smsSend = useAjax((params) => smsSendApi(params))
    const [msg, setMsg] = useState<string | number>('发送验证码')
    /*********************************/

    // 倒计时
    const timeOut = (num: number) => {
        let timer: any = null
        if (num > 0) {
            timer = setTimeout(() => {
                setMsg(num - 1)
                timeOut(num - 1)
                clearTimeout(timer)
                timer = null
            }, 1000)
        } else {
            setMsg('发送验证码')
        }
    }

    const sendMsg = () => {
        if (!isMobile(mobile)) {
            message.error('请输入正确的手机号')
            return
        }
        smsSend.run({ mobile, type: msgType }).then(res => {
            if (res) {
                message.success('发送成功')
                setMsg(60)
                timeOut(60)
            }
        })
    }

    return <Space>
        <Input {...inputProps} />
        <Button size={inputProps.size} style={{ width: 90, fontSize: 12 }} onClick={() => sendMsg()} disabled={msg !== '发送验证码'}>{msg === '发送验证码' ? msg : msg + 's'}</Button>
    </Space>
}

export default React.memo(CodeInput)