import { Button } from 'antd';
import { ModalStaticFunctions } from 'antd/es/modal/confirm';
import React, { useState } from 'react';
import ReactDOM from 'react-dom/client'
import { getOrientation, isOs } from '../utils';
import { CheckCircleFilled, CloseCircleFilled } from '@ant-design/icons';

let os = isOs()

// 创建容器
const el = document.createElement("div");
document.body.append(el);
el.className = 'my-modal'

const root = ReactDOM.createRoot(el);

// 用于暴露 Notifications 里面的方法
const notificationRef: any = React.createRef();


const NotificationItem: React.FC<{ title?: string, content?: string, onRemove?: () => void; type: 'SUCC' | 'ERR' | 'INFO' }> = ({ title, content, type, onRemove }) => {


    return <div className='pop'>
        <div className='pop_body' style={{ transform: 'rotate(90deg)' }}>
            <div className='modal_body_content'>
                {type === 'SUCC' ? <CheckCircleFilled className='modal_icon' style={{ color: '#52c41a' }} /> : type === 'ERR' ? <CloseCircleFilled className='modal_icon' style={{ color: '#ff4d4f' }} /> : null}
                {title && <span className='modal_title'>{title}</span>}
                {content && <div className='modal_content'>{content}</div>}
            </div>
            <div className='modal_body_bts'>
                <Button style={{ backgroundColor: '#31db8b' }} type='primary' onClick={onRemove}>确定</Button>
            </div>
        </div>
    </div>
}

const Notifications = React.forwardRef((_props, ref) => {
    // 通知列表
    const [open, setOpen] = useState<boolean>(false)
    const [content, setContent] = useState<{ title?: string, content?: string, type: 'SUCC' | 'ERR' | 'INFO' }>({ type: 'INFO' })


    React.useImperativeHandle(ref, () => ({
        notify({ title, content, type }: { type: 'SUCC' | 'ERR' | 'INFO', title?: string, content?: string }) {
            setContent({ title, content, type })
            setOpen(true)
        }
    }), []);

    return open ? <NotificationItem
        onRemove={() => { setOpen(false), setContent({ type: 'INFO' }) }}
        {...content}
    /> : null
})

root.render(<Notifications ref={notificationRef} />);

type ModalType = Omit<ModalStaticFunctions, 'warn'>;

const showModal = {
    success: ({ modal, title, content }: { modal: ModalType, title?: string, content?: string }) => {
        if (['ios', 'android'].includes(os) && getOrientation() === 'VERTICAL') {
            notificationRef.current.notify({ title, content, type: 'SUCC' });
        } else {
            modal.success({
                style: { maxWidth: 300 },
                title,
                content,
                okText: '确定'
            });
        }
    },
    error: ({ modal, title, content }: { modal: ModalType, title?: string, content?: string }) => {
        if (['ios', 'android'].includes(os) && getOrientation() === 'VERTICAL') {
            notificationRef.current.notify({ title, content, type: 'ERR' });
        } else {
            modal.error({ style: { maxWidth: 300 }, title: title, content, okText: '确定' });
        }
    },
    info: ({ modal, title, content }: { modal: ModalType, title?: string, content?: string }) => {
        if (['ios', 'android'].includes(os) && getOrientation() === 'VERTICAL') {
            notificationRef.current.notify({ title, content, type: 'INFO' });
        } else {
            modal.info({
                title,
                content,
                style: { maxWidth: 300 },
                icon: null,
                okText: '确定'
            })
        }
    },
}

export default showModal