import { useReducer } from "react"
import { getToken } from "../utils/auth"
import { useAjax } from "../hooks/useAjax"
import { getUserDetailApi } from "../api"

export enum TYPESWITCH {
    'USER_LOGIN' = '用户密码登录',
    'PHONE_LOGIN' = '手机号登录',
    'USER_REG' = '用户注册',
    'PHONE_REG' = '手机号注册',
    'PWD' = '找回密码'
}

export interface State {
    // 屏幕方向 VERTICAL 竖屏 LANDSCAPE 横屏
    orientation: 'LANDSCAPE' | 'VERTICAL',
    isPut: boolean
    // 首次进来弹绑定手机号控制
    isBind: boolean
    // 首次进来弹实名认证控制
    isAuth: boolean
    token: string
    // 页面类型
    typeSwitch: string
    // 初始化数据
    initData: any
    // 用户数据
    userData: any
}

export interface Action {
    type: 'setTypeSwitch' | 'setInitData' | 'setUserData' | 'setToken' | 'setIsBind' | 'setIsAuth' | 'setIsPut' | 'setOrientation',
    params: any
}

const reducer: React.Reducer<State, Action> = (state, action) => {
    const { type, params } = action
    switch (type) {
        case 'setToken':
            return { ...state, token: params?.token }
        case 'setTypeSwitch':
            return { ...state, typeSwitch: params?.typeSwitch }
        case 'setInitData':
            return { ...state, initData: params?.initData }
        case 'setUserData':
            return { ...state, userData: params?.userData }
        case 'setIsBind':
            return { ...state, isBind: params?.isBind }
        case 'setIsAuth':
            return { ...state, isAuth: params?.isAuth }
        case 'setIsPut':
            return { ...state, isPut: params?.isPut }
        case 'setOrientation':
            return { ...state, orientation: params?.orientation }
        default:
            return state;
    }
}

const initialState: State = {
    orientation: 'LANDSCAPE',
    isPut: false,
    isBind: false,
    isAuth: false,
    token: getToken() || '',
    typeSwitch: 'USER_LOGIN',
    // 初始化数据
    initData: {},
    // 用户数据
    userData: {}
}

/**
 * 处理初始化数据 登录数据等 公共数据等
 * @returns 
 */
export default function useConfig() {

    const [state, dispatch] = useReducer(reducer, initialState)
    const getUserDetail = useAjax(() => getUserDetailApi())
    
    // 获取用户详情
	const getDetails = () => {
		getUserDetail.run().then(res => {
			if (res?.data) {
				dispatch({ type: 'setUserData', params: { userData: res?.data } })
			}
		})
	}

    return {
        state,
        dispatch,
        getDetails
    }
}